ArrowItem — pyqtgraph 0.11.0rc0 documentation

# ArrowItem

class `pyqtgraph.` `ArrowItem`(**opts)

  For displaying scale-invariant arrows. For arrows pointing to a location on a curve, see CurveArrow

  `__init__`(**opts)

    Arrows can be initialized with any keyword arguments accepted by the setStyle() method.

  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)
  `setStyle`(**opts)

    Changes the appearance of the arrow. All arguments are optional:

    Keyword Arguments: |
    angle | Orientation of the arrow in degrees. Default is 0; arrow pointing to the left.
    headLen | Length of the arrow head, from tip to base. default=20
    headWidth | Width of the arrow head at its base.
    tipAngle | Angle of the tip of the arrow in degrees. Smaller values make a ‘sharper’ arrow. If tipAngle is specified, ot overrides headWidth. default=25
    baseAngle | Angle of the base of the arrow head. Default is 0, which means that the base of the arrow head is perpendicular to the arrow tail.
    tailLen | Length of the arrow tail, measured from the base of the arrow head to the end of the tail. If this value is None, no tail will be drawn. default=None
    tailWidth | Width of the tail. default=3
    pen | The pen used to draw the outline of the arrow.
    brush | The brush used to fill the arrow.

  `shape`(self) → PySide2.QtGui.QPainterPath